@@ -2,7 +2,7 @@
 * socket.cpp: socket management
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: socket.cpp,v 1.1 2001/10/06 21:23:36 bozo Exp $
+* $Id: socket.cpp,v 1.2 2001/10/16 12:24:39 bozo Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -72,20 +72,15 @@
 //------------------------------------------------------------------------------
 // Plateform specific issues
 //------------------------------------------------------------------------------
-#ifdef SOCKLEN_T_IN_UNISTD_H
-#define ERR_INTR        EINTR
-#define bufftype        byte
-#define socklen         socklen_t
-
-#elif defined WIN32
+#if defined WIN32
 #define ERR_INTR        WSAEINTR
 #define bufftype        char
 #define socklen         int
 
-#else /* default values, for instance under Solaris */
+#else
 #define ERR_INTR        EINTR
-#define bufftype        char
-#define socklen         int
+#define bufftype        byte
+#define socklen         socklen_t
 
 #endif
 
